**********
User Guide
**********

.. admonition:: Work in Progress
   :class: warning

   The user guide is incomplete. For the full list of packages and modules
   provided by ERLabPy, see :doc:`../reference`.

This section contains some examples for getting started with ARPES data analysis
and visualization.


Introduction
============

The following documentation assumes basic python programming experience.

If you are new to scientific programming in python altogether, `Scientific
Python Lectures <https://github.com/jrjohansson/scientific-python-lectures>`_ is
a great resource to get started.

Data in ERLabPy are mostly represented by :mod:`xarray` objects
:cite:p:`hoyer2017xarray`. The `xarray user guide
<https://docs.xarray.dev/en/stable/index.html>`_ and the `xarray tutorial
<https://tutorial.xarray.dev/>`_ are great resources to get started with xarray.

.. toctree::
   io
   indexing
   plotting
   kconv

Further reading
===============

- `Lectures on scientific computing with Python
  <https://github.com/jrjohansson/scientific-python-lectures>`_
- `The beginner's guide to numpy
  <https://numpy.org/doc/stable/user/absolute_beginners.html>`_
- `Xarray tutorial <https://tutorial.xarray.dev/>`_
